@@ -1,12 +1,13 @@
+use crate::data::primitive::PrimitiveObject;
 use crate::data::Literal;
-use crate::data::primitive::{PrimitiveObject};
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq)]
 pub enum MemoryType {
     Event(String),
     Metadata,
     Use,
     Remember,
+    Constant,
 }
 
 #[derive(Debug, Clone)]
