@@ -8,9 +8,14 @@ use crate::interpreter::{
     json_to_rust::interpolate,
 };
 
-use std::{collections::HashMap, env, sync::mpsc};
+use std::{collections::HashMap, sync::mpsc};
 
-fn format_body(args: &ArgsType, flow_name: &str, interval: Interval, client: Client) -> Result<Literal, ErrorInfo> {
+fn format_body(
+    args: &ArgsType,
+    flow_name: &str,
+    interval: Interval,
+    client: Client,
+) -> Result<Literal, ErrorInfo> {
     let mut map: HashMap<String, Literal> = HashMap::new();
 
     match args.get("fn_id", 0) {
@@ -62,16 +67,6 @@ fn format_headers(interval: Interval) -> HashMap<String, Literal> {
         PrimitiveString::get_literal("application/json,text/*", interval),
     );
 
-    match env::var("FN_X_API_KEY") {
-        Ok(value) => {
-            header.insert(
-                "X-Api-Key".to_owned(),
-                PrimitiveString::get_literal(&value, interval),
-            );
-        }
-        Err(_e) => {}
-    };
-
     header
 }
 
@@ -85,8 +80,8 @@ pub fn api(
     let (client, url) = match &data.context.api_info {
         Some(ApiInfo {
             client,
-            fn_endpoint,
-        }) => (client.to_owned(), fn_endpoint.to_owned()),
+            apps_endpoint,
+        }) => (client.to_owned(), apps_endpoint.to_owned()),
         None => {
             return Err(gen_error_info(
                 Position::new(interval, &data.context.flow),
@@ -108,11 +103,20 @@ pub fn api(
     http.insert("header".to_owned(), lit_header);
     http.insert("body".to_owned(), body);
 
-    match http_request(&http, "post", &data.context.flow, interval) {
-        Ok(value) => match value.get("data") {
-            Some(value) => interpolate(value, interval, data, msg_data, sender),
+    match http_request(&http, "post", &data.context.flow, interval, true) {
+        Ok((value, response_info)) => match value.get("data") {
+            Some(value) => {
+                let mut literal = interpolate(value, interval, data, msg_data, sender)?;
+                // add additional information about the http request response: status and headers
+                literal.add_info_block(response_info);
+
+                Ok(literal)
+            }
             None => {
-                let err = gen_error_info(Position::new(interval, &data.context.flow), ERROR_HTTP_NOT_DATA.to_owned());
+                let err = gen_error_info(
+                    Position::new(interval, &data.context.flow),
+                    ERROR_HTTP_NOT_DATA.to_owned(),
+                );
                 Ok(MSG::send_error_msg(sender, msg_data, Err(err)))
             }
         },
