@@ -1,9 +1,9 @@
 use crate::data::{ast::*, tokens::*};
 use crate::error_format::{gen_nom_failure, ERROR_GOTO_STEP};
 use crate::parser::{
-    parse_path::parse_path, parse_var_types::parse_idents_expr_usage,
     get_interval, parse_comments::comment, parse_idents::parse_string_assignation,
-    tools::get_string, tools::get_tag, GotoType, GotoValueType,
+    parse_path::parse_path, parse_var_types::parse_idents_expr_usage, tools::get_string,
+    tools::get_tag, GotoType, GotoValueType,
 };
 
 use nom::{branch::alt, bytes::complete::tag, combinator::opt, error::*, sequence::preceded, *};
@@ -14,7 +14,7 @@ use nom::{branch::alt, bytes::complete::tag, combinator::opt, error::*, sequence
 
 fn get_variable<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoValueType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, ..) = tag(DOLLAR)(s)?;
 
@@ -26,7 +26,7 @@ where
 
 fn get_name<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoValueType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, position) = get_interval(s)?;
     let (s, name) = parse_string_assignation(s)?;
@@ -36,14 +36,14 @@ where
 
 fn get_goto_value_type<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoValueType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     alt((get_variable, get_name))(s)
 }
 
 fn get_step<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, name) = preceded(comment, get_string)(s)?;
     let (s, ..) = get_tag(name, STEP)(s)?;
@@ -55,7 +55,7 @@ where
 
 fn get_flow<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, name) = preceded(comment, get_string)(s)?;
     let (s, ..) = get_tag(name, FLOW)(s)?;
@@ -67,7 +67,7 @@ where
 
 fn get_step_at_flow<'a, E>(s: Span<'a>) -> IResult<Span<'a>, GotoType, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, ..) = comment(s)?;
 
@@ -88,7 +88,7 @@ where
 
 pub fn parse_goto<'a, E>(s: Span<'a>) -> IResult<Span<'a>, Expr, E>
 where
-    E: ParseError<Span<'a>>,
+    E: ParseError<Span<'a>> + ContextError<Span<'a>>,
 {
     let (s, name) = preceded(comment, get_string)(s)?;
     let (s, ..) = get_tag(name, GOTO)(s)?;
@@ -97,8 +97,5 @@ where
 
     let (s, goto_type) = alt((get_step, get_flow, get_step_at_flow))(s)?;
 
-    Ok((
-        s,
-        Expr::ObjectExpr(ObjectType::Goto(goto_type, interval)),
-    ))
+    Ok((s, Expr::ObjectExpr(ObjectType::Goto(goto_type, interval))))
 }
