@@ -61,7 +61,8 @@ fn hold_test_some_0() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "start",
             "flow",
@@ -92,7 +93,8 @@ fn hold_test_some_3() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "start",
             "flow",
@@ -123,7 +125,8 @@ fn hold_test_some_7() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "start",
             "flow",
@@ -154,7 +157,8 @@ fn hold_test_some_8() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "start",
             "flow",
@@ -185,7 +189,8 @@ fn hold_test_some_17() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "start",
             "flow",
@@ -199,7 +204,6 @@ fn hold_test_some_17() {
     assert_eq!(v1, v2)
 }
 
-
 #[test]
 fn hold_test_step_1_ok() {
     let data = r#"{"memories":[], "messages":[{"content":{"text":"OK"}, "content_type":"text"}] }"#;
@@ -217,7 +221,8 @@ fn hold_test_step_1_ok() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "hold_1_ok",
             "flow",
@@ -248,7 +253,8 @@ fn hold_test_step_2_ok() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "hold_2_ok",
             "flow",
@@ -279,7 +285,8 @@ fn hold_test_step_3_ok() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "hold_3_ok",
             "flow",
@@ -310,7 +317,8 @@ fn hold_test_step_4_ok() {
                 serde_json::json!({}),
                 "".to_owned(),
                 "".to_owned(),
-                None
+                None,
+                false,
             )),
             "hold_4_ok",
             "flow",
@@ -322,4 +330,4 @@ fn hold_test_step_4_ok() {
     let v2: Value = serde_json::from_str(data).unwrap();
 
     assert_eq!(v1, v2)
-}
\ No newline at end of file
+}
